==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ChaikinVolatilityIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicator, _super);
    function ChaikinVolatilityIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicator.prototype.get_t4 = function () {
        return new ChaikinVolatilityIndicatorStrategy();
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "t4", {
        get: function () {
            return this.get_t4();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.get_uh = function () {
        return ChaikinVolatilityIndicator.$;
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "up", {
        get: function () {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.uq));
        },
        set: function (a) {
            this.h(ChaikinVolatilityIndicator.uq, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.ua = function () {
        return this.up;
    };
    ChaikinVolatilityIndicator.prototype.uj = function (a) {
        this.up = a;
    };
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.uq = StrategyBasedIndicator.um(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
}(StrategyBasedIndicator));
export { ChaikinVolatilityIndicator };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ChaikinVolatilityIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicator, _super);
    function ChaikinVolatilityIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicator.prototype.get_uh = function () {
        return new ChaikinVolatilityIndicatorStrategy();
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.get_uu = function () {
        return ChaikinVolatilityIndicator.$;
    };
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinVolatilityIndicator.prototype, "u2", {
        get: function () {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.u3));
        },
        set: function (a) {
            this.h(ChaikinVolatilityIndicator.u3, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinVolatilityIndicator.prototype.un = function () {
        return this.u2;
    };
    ChaikinVolatilityIndicator.prototype.uw = function (a) {
        this.u2 = a;
    };
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.u3 = StrategyBasedIndicator.uz(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
}(StrategyBasedIndicator));
export { ChaikinVolatilityIndicator };
